/* ============================================================================
 * Project Name: BLDC_02a
 *
 * Description:
 *   PSoC5 demo showing 3-phase PWM output generator using 180-degree modulation
 *   with variable frequency and duty cycle.
 *
 *   Frequency range [1kHz to 10kHz], resolution 32-bit (~0.01 Hz)
 *   Duty cycle range [0 to 255], resolution 8-bit
 *    
 *   Frequency adjustment achieved using DDS32 as PWM clock
 *   Amplitude adjustment achived by varying PWM compare
 *
 *   Rotary encoder is used to adjust frequency and amplitude.
 *
 * Uses:
 *   project uses several custom components:
 *
 *   DDS32 v0.1   
 *   https://community.cypress.com/t5/Code-Examples/DDS24-24-bit-DDS-arbitrary-frequency-generator-component/m-p/46587/highlight/true#M155

 *   QuadDec_SW 0.1
 *   https://community.cypress.com/t5/Code-Examples/Quad-Decoder-with-Button-Switch-component-for-rotary-shaft/td-p/121267
 *
 *   PSoC Annotation Library 1.0
 *   https://community.cypress.com/t5/Code-Examples/PSoC-Annotation-Library-v1-0/m-p/62657#M245
 *
 *   Sync32 v0.0
 *   https://community.cypress.com/t5/Code-Examples/Sync32-custom-component-for-PSoC5-and-PSoC4/m-p/31243
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/

#include "project.h"

#define BlinkLED(); {Pin_LED_Write(1); CyDelayUs(50); Pin_LED_Write(0);} // blink LED indicator


//===========================================
// Global variables
//===========================================

//===========================================
// Forward declarations
//===========================================


void Init()
{
    CyGlobalIntEnable; /* Enable global interrupts. */

    Decoder_1_Start();

 
    
    Count7_1_Start();
    PWM_1_Start();
    //PWM_1_WriteCompare(Decoder_1_Position); // update duty cycle
    
    DDS_1_Start();                              // start DDS
    //DDS_1_SetFrequency(6*Decoder_1_Position);   // update frequency

    
}


int main(void)
{

    Init();
    
    for(;;)
    {
        
        if (Decoder_1_PositionChanged)
        {
            BlinkLED();
            PWM_1_WriteCompare(Decoder_1_Position); // update duty cycle
        }
        
        /*
        if (Decoder_1_PositionChanged)
        {
            BlinkLED();
            DDS_1_SetFrequency(3*Decoder_1_Position); // update frequency
        }
        */

        
        if (Decoder_1_BtnPressed)
        {
            BlinkLED();
            Decoder_1_SetPosition(Decoder_1_StartPosition);
        }
        
    }
}

/* [] END OF FILE */
